@@ -52,7 +52,7 @@ class GraphUtils:
       self.sobjects = obj__
       # Add random color for object if it's not there
       for obj in self.sobjects:
-        if obj not in self.object_to_colors.keys():
+        if obj not in self.objects_to_colors.keys():
           self.objects_to_colors['{obj}'] = "#"+''.join([random.choice('0123456789ABCDEF') for j in range(6)])
 
     def visualize_using_boxplot(self, obj_: object, numcols: int,release_criteria: int, ylimit=None):
